@@ -32,10 +32,11 @@ static int io_multiplexing_in;
 static int multiplex_in_fd;
 static int multiplex_out_fd;
 static time_t last_io;
-
+static int eof_error=1;
 extern int verbose;
 extern int io_timeout;
 
+
 int64 write_total(void)
 {
 	return total_written;
@@ -119,7 +120,9 @@ static int read_timeout(int fd, char *buf, int len)
 		}
 
 		if (n == 0) {
-			rprintf(FERROR,"EOF in read_timeout\n");
+			if (eof_error) {
+				rprintf(FERROR,"EOF in read_timeout\n");
+			}
 			exit_cleanup(1);
 		}
 
@@ -142,7 +145,7 @@ static void read_loop(int fd, char *buf, int len)
 	}
 }
 
-/* read from the file descriptor handing multiplexing - 
+/* read from the file descriptor handling multiplexing - 
    return number of bytes read
    never return <= 0 */
 static int read_unbuffered(int fd, char *buf, int len)
@@ -220,10 +223,7 @@ static void read_check(int f)
 
 	if (n > (read_buffer_size - read_buffer_len)) {
 		read_buffer_size += n;
-		if (!read_buffer)
-			read_buffer = (char *)malloc(read_buffer_size);
-		else
-			read_buffer = (char *)realloc(read_buffer,read_buffer_size);
+		read_buffer = (char *)Realloc(read_buffer,read_buffer_size);
 		if (!read_buffer) out_of_memory("read check");      
 		read_buffer_p = read_buffer;      
 	}
@@ -482,8 +482,12 @@ void write_byte(int f,unsigned char c)
 
 int read_line(int f, char *buf, int maxlen)
 {
+	eof_error = 0;
+
 	while (maxlen) {
+		buf[0] = 0;
 		read_buf(f, buf, 1);
+		if (buf[0] == 0) return 0;
 		if (buf[0] == '\n') {
 			buf[0] = 0;
 			break;
@@ -497,6 +501,9 @@ int read_line(int f, char *buf, int maxlen)
 		*buf = 0;
 		return 0;
 	}
+
+	eof_error = 1;
+
 	return 1;
 }
 
