@@ -553,3 +553,9 @@ int slprintf(char *str, int n, char *format, ...)
 	return ret;
 }
 
+
+void *Realloc(void *p, int size)
+{
+	if (!p) return (void *)malloc(size);
+	return (void *)realloc(p, size);
+}
